==> apache-dubbo-3.0.5-src.zip: apache-dubbo-3.0.5-src/dubbo-plugin/dubbo-qos/src/main/java/org/apache/dubbo/qos/probe/impl/ProviderReadinessProbe.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.qos.probe.impl;

import org.apache.dubbo.common.extension.Activate;
import org.apache.dubbo.qos.probe.ReadinessProbe;
import org.apache.dubbo.rpc.model.FrameworkModel;
import org.apache.dubbo.rpc.model.FrameworkServiceRepository;
import org.apache.dubbo.rpc.model.ProviderModel;

import java.util.Collection;
import java.util.List;

@Activate
public class ProviderReadinessProbe implements ReadinessProbe {


    private static FrameworkServiceRepository serviceRepository = FrameworkModel.defaultModel().getServiceRepository();

    @Override
    public boolean check() {
        Collection<ProviderModel> providerModelList = serviceRepository.allProviderModels();
        if (providerModelList.isEmpty()) {
            return true;
        }

        boolean hasService = false;
        for (ProviderModel providerModel : providerModelList) {
            List<ProviderModel.RegisterStatedURL> statedUrls = providerModel.getStatedUrl();
            for (ProviderModel.RegisterStatedURL statedUrl : statedUrls) {
                if (statedUrl.isRegistered()) {
                    hasService = true;
                    break;
                }
            }
        }

        return hasService;
    }
}

==> apache-dubbo-3.0.11-src.zip: apache-dubbo-3.0.11-src/dubbo-plugin/dubbo-qos/src/main/java/org/apache/dubbo/qos/probe/impl/ProviderReadinessProbe.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.qos.probe.impl;

import org.apache.dubbo.common.extension.Activate;
import org.apache.dubbo.qos.probe.ReadinessProbe;
import org.apache.dubbo.rpc.model.FrameworkModel;
import org.apache.dubbo.rpc.model.FrameworkServiceRepository;
import org.apache.dubbo.rpc.model.ProviderModel;

import java.util.Collection;
import java.util.List;

@Activate
public class ProviderReadinessProbe implements ReadinessProbe {
    private FrameworkModel frameworkModel;
    private FrameworkServiceRepository serviceRepository;

    public ProviderReadinessProbe(FrameworkModel frameworkModel) {
        if (frameworkModel != null) {
            this.frameworkModel = frameworkModel;
        } else {
            this.frameworkModel = FrameworkModel.defaultModel();
        }
        this.serviceRepository = this.frameworkModel.getServiceRepository();
    }

    @Override
    public boolean check() {
        Collection<ProviderModel> providerModelList = serviceRepository.allProviderModels();
        if (providerModelList.isEmpty()) {
            return true;
        }

        boolean hasService = false;
        for (ProviderModel providerModel : providerModelList) {
            List<ProviderModel.RegisterStatedURL> statedUrls = providerModel.getStatedUrl();
            for (ProviderModel.RegisterStatedURL statedUrl : statedUrls) {
                if (statedUrl.isRegistered()) {
                    hasService = true;
                    break;
                }
            }
        }

        return hasService;
    }
}
